@@ -271,7 +271,7 @@ pid_t fork_cgi_process(t_session *session, t_cgi_info *cgi_info) {
 					setenv("CGIWRAP_FOLLOWSYMLINKS", "false", 1);
 				}
 				cgi_time[15] = '\0';
-				snprintf(cgi_time, 15, "%d", session->config->time_for_cgi);
+				snprintf(cgi_time, 15, "%d", session->host->time_for_cgi);
 				setenv("CGIWRAP_TIMEFORCGI", cgi_time, 1);
 				if (session->config->user_directory_set) {
 					setenv("CGIWRAP_USERDIRECTORY", session->config->user_directory, 1);
