@@ -3,6 +3,7 @@
 
 #include <stdbool.h>
 #include "liblist.h"
+#include "libip.h"
 #include "session.h"
 
 #define FCGI_VERSION_1           1
@@ -49,7 +50,7 @@ typedef struct type_cgi_info {
 /* FastCGI server loadbalancer
  */
 void init_load_balancer(t_fcgi_server *fcgi_server);
-t_connect_to *select_connect_to(t_fcgi_server *fcgi_server, t_ipv4 client_ip);
+t_connect_to *select_connect_to(t_fcgi_server *fcgi_server, t_ip_addr *client_ip);
 t_fcgi_server *fcgi_server_match(t_fcgi_server *fcgi_server, t_charlist *fastcgi, char *cgi_script);
 void check_load_balancer(t_config *config);
 
