@@ -50,6 +50,9 @@
 #ifdef HAVE_REWRITE
 #include "rewrite.h"
 #endif
+#ifdef HAVE_XSLT
+#include "xslt.h"
+#endif
 
 #define REQUEST_BUFFER_CHUNK     4 * KILOBYTE
 #define MAIN_LOOP_TIMER          1
@@ -209,10 +212,15 @@ int handle_error(t_session *session, int error_code) {
 		strcpy(session->file_on_disk + length, error_handler);
 
 		session->cgi_type = no_cgi;
+			
 		check_target_is_cgi(session);
 
 		if (session->cgi_type != no_cgi) {
 			result = execute_cgi(session);
+#ifdef HAVE_XSLT
+		} else if (can_transform_with_xslt(session)) {
+			result = handle_xml_file(session);
+#endif
 		} else switch (is_directory(session->file_on_disk)) {
 			case error:
 				result = 500;
@@ -1027,6 +1035,10 @@ int serve_client(t_session *session) {
 			if (session->cgi_type != no_cgi) {
 				session->body = NULL;
 				result = execute_cgi(session);
+#ifdef HAVE_XSLT
+			} else if (can_transform_with_xslt(session)) {
+				result = handle_xml_file(session);
+#endif
 			} else {
 				result = send_file(session);
 			}
@@ -1203,7 +1215,10 @@ void connection_handler(t_session *session) {
 		do {
 			result = serve_client(session);
 			handle_request_result(session, result);
-			send_buffer(session, NULL, 0); /* Flush the output-buffer */
+
+			if (session->socket_open) {
+				send_buffer(session, NULL, 0); /* Flush the output-buffer */
+			}
 
 			reset_session(session);
 
@@ -1216,7 +1231,7 @@ void connection_handler(t_session *session) {
 					}
 				}
 			}
-		} while (session->keep_alive);
+		} while (session->keep_alive && session->socket_open);
 
 		destroy_session(session);
 		close_socket(session);
@@ -1707,6 +1722,9 @@ int run_server(t_settings *settings) {
 #ifdef HAVE_COMMAND
 	init_command_module();
 #endif
+#ifdef HAVE_XSLT
+	init_xslt_module();
+#endif
 
 	/* Redirecting I/O to /dev/null
 	 */
