@@ -223,15 +223,7 @@ static bool digest_http_authentication(t_session *session, char *auth_str) {
 		key = rest;
 	}
 
-	if (session->vars != NULL) {
-		if (strncmp(session->uri, uri, session->uri_len) != 0) {
-			return false;
-		} else if (*(uri + session->uri_len) != '?') {
-			return false;
-		} else if (strcmp(session->vars, uri + session->uri_len + 1) != 0) {
-			return false;
-		}
-	} else if (strcmp(session->uri, uri) != 0) {
+	if (strcmp(session->request_uri, uri) != 0) {
 		return false;
 	}
 
@@ -287,8 +279,10 @@ bool http_authentication_oke(t_session *session, bool on_pwdfile_missing) {
 	} else if ((auth_str = get_headerfield("Authorization:", session->headerfields)) != NULL) {
 		auth_str = strdup(auth_str);
 		if ((strncmp(auth_str, "Basic ", 6) == 0) && (session->host->auth_method == basic)) {
+			session->http_auth = basic;
 			result = basic_http_authentication(session, auth_str + 6);
 		} else if ((strncmp(auth_str, "Digest ", 7) == 0) && (session->host->auth_method == digest)) {
+			session->http_auth = digest;
 			result = digest_http_authentication(session, auth_str + 7);
 		}
 		free(auth_str);
