@@ -4,6 +4,6 @@
 #include "session.h"
 
 bool group_oke(t_session *session, char *user, t_charlist *group);
-bool http_authentication_oke(t_session *session);
+bool http_authentication_oke(t_session *session, bool on_pwdfile_missing);
 
 #endif
