@@ -178,7 +178,7 @@ int parse_ip_port(char *line, t_ip_addr *ip, int *port) {
 		} while ((*s_port != ':') && (*s_port != '.'));
 		sep = *s_port;
 		*s_port = '\0';
-		s_ip = remove_spaces(s_ip);
+		s_ip = remove_spaces(line);
 		s_port = remove_spaces(s_port + 1);
 	}
 
