@@ -199,12 +199,17 @@ SSL_CTX *ssl_binding(char *keyfile, char *CA_cert, int verify_depth, char *dh_fi
 }
 
 bool ssl_accept(int sock, SSL **ssl, SSL_CTX *context) {
-	BIO * bio;
+	BIO *bio;
 	int result;
 
-	bio = BIO_new_socket(sock, 0);
-	*ssl = SSL_new(context);
+	if ((bio = BIO_new_socket(sock, 0)) == NULL) {
+		return false;
+	} else if ((*ssl = SSL_new(context)) == NULL) {
+		return false;
+	}
+
 	SSL_set_bio(*ssl, bio, bio);
+
 	if ((result = SSL_accept(*ssl)) != 1) {
 #ifdef DEBUG
 		fprintf(stderr, "SSL_accept(): ");
