@@ -3,8 +3,11 @@
 #include <stdlib.h>
 #include <stdbool.h>
 #include <string.h>
+#include <limits.h>
 #include "alternative.h"
 
+#define MAX_VALUE (INT_MAX - 10) / 10
+
 /* Convert a string to a integer.
  */
 int str2int(const char *str) {
@@ -16,6 +19,9 @@ int str2int(const char *str) {
 		return -1;
 	} else while (*(str + i) != '\0') {
 		if ((*(str + i) >= '0') && (*(str + i) <= '9')) {
+			if (value >= MAX_VALUE) {
+				return -1;
+			}
 			value *= 10;
 			value += (*(str + i) - '0');
 			i++;
@@ -232,8 +238,10 @@ int prevent_CMDi(char *line) {
 	short low, high;
 	char value, *prot;
 
-	if ((prot = strcasestr(line, "http://")) != NULL) {
-		memcpy(prot, "XXXX", 4);
+	prot = line;
+	while ((prot = strcasestr(prot, "http://")) != NULL) {
+		memcpy(prot, "xxxx", 4);
+		prot += 7;
 	}
 
 	if (line != NULL) {
