@@ -11,7 +11,7 @@ int  split_string(const char *str, char **key, char **value, char c);
 int  split_configline(const char *str, char **key, char **value);
 bool valid_uri(char *uri);
 void url_decode(char *line);
-void remove_dangerous_chars(char *line);
+bool forbidden_chars_present(char *line);
 int  prevent_CMDi(char *line);
 int  prevent_SQLi(char *line, int length, char **newline);
 int  prevent_XSS(char *line);
