@@ -271,9 +271,21 @@ void log_request(t_session *session, int code) {
 /* Log garbage sent by a client.
  */
 void log_garbage(t_session *session) {
+	int i, spaces = 2;
 	FILE *fp;
 	char str[TIMESTAMP_SIZE + IP_ADDRESS_SIZE];
 
+	for (i = 0; i < session->bytes_in_buffer; i++) {
+		if (session->request[i] == '\0') {
+			if (spaces > 0) {
+				session->request[i] = ' ';
+				spaces--;
+			} else {
+				session->request[i] = '\r';
+			}
+		}
+	}
+
 	if ((session->config->garbage_logfile != NULL) && (session->request != NULL)) {
 		if ((fp = fopen(session->config->garbage_logfile, "a")) != NULL) {
 			print_ip_address(str, &(session->ip_address));
