@@ -379,12 +379,11 @@ int send_code(t_session *session, int code) {
 			if (send_buffer(session, session->uri, session->uri_len) == -1) {
 				return -1;
 			}
-#ifdef HAVE_SSL
-			if (session->cause_of_301 == missing_slash)
-#endif
+			if (session->cause_of_301 == missing_slash) {
 				if (send_buffer(session, "/", 1) == -1) {
 					return -1;
 				}
+			}
 
 			if (session->vars != NULL) {
 				if (send_buffer(session, "?", 1) == -1) {
