@@ -83,6 +83,9 @@ static t_host *new_host(void) {
 		host->alias              = NULL;
 #ifdef HAVE_SSL
 		host->require_ssl        = false;
+#endif
+#ifdef HAVE_XSLT
+		host->use_xslt           = false;
 #endif
 		host->prevent_cmdi       = false;
 		host->prevent_sqli       = false;
@@ -304,12 +307,10 @@ static int fgets_multi(char *line, int size, FILE *fp) {
 		return -1;
 	} else if (fgets(line, size, fp) != NULL) {
 		if ((pos = strstr(line, " \\\n")) == NULL) {
-#ifdef CYGWIN
 			pos = strstr(line, " \\\r");
 		}
 
 		if (pos == NULL) {
-#endif
 			lines = 0;
 		} else if ((lines = fgets_multi(pos, size - (pos - line), fp)) == -1) {
 			return -1;
@@ -1166,6 +1167,12 @@ static bool host_setting(char *key, char *value, t_host *host) {
 		if (parse_yesno(value, &(host->user_websites)) == 0) {
 			return true;
 		}
+#ifdef HAVE_XSLT
+	} else if (strcmp(key, "usexslt") == 0) {
+		if (parse_yesno(value, &(host->use_xslt)) == 0) {
+			return true;
+		}
+#endif
 	} else if (strcmp(key, "volatileobject") == 0) {
 		if (*value == '/') {
 			host->volatile_object.size++;
