@@ -173,6 +173,9 @@ typedef struct type_host {
 #endif
 #ifdef HAVE_SSL
     bool          require_ssl;
+#endif
+#ifdef HAVE_XSLT
+	bool          use_xslt;
 #endif
 	bool          prevent_cmdi;
 	bool          prevent_sqli;
