@@ -72,6 +72,9 @@ static void clear_session(t_session *session) {
 #ifdef DEBUG
 	session->status = NULL;
 #endif
+#ifdef HAVE_XSLT
+	session->xslt_file = NULL;
+#endif
 }
 
 /* Initialize a session-record.
@@ -108,6 +111,9 @@ void reset_session(t_session *session) {
 	sfree(session->path_info);
 	sfree(session->request_uri);
 	sfree(session->location);
+#ifdef HAVE_XSLT
+	sfree(session->xslt_file);
+#endif
 	if (session->uploaded_file != NULL) {
 		unlink(session->uploaded_file);
 		free(session->uploaded_file);
