@@ -38,6 +38,9 @@
 #ifdef HAVE_COMMAND
 #include "command.h"
 #endif
+#ifdef HAVE_XSLT
+#include "xslt.h"
+#endif
 
 #define MAX_VOLATILE_SIZE      1 * MEGABYTE
 #define FILE_BUFFER_SIZE      32 * KILOBYTE
@@ -941,6 +944,7 @@ int show_index(t_session *session) {
 	if (session->host->follow_symlinks == false) {
 		switch (contains_not_allowed_symlink(session->file_on_disk, session->host->website_root)) {
 			case error:
+				log_error(session, "error while scanning file for symlinks");
 				return 500;
 			case not_found:
 				return 404;
@@ -1156,14 +1160,13 @@ int handle_options_request(t_session *session) {
 	int code = 200, handle;
 
 	if ((handle = open(session->file_on_disk, O_RDONLY)) == -1) {
-		if (session->uri_is_dir) {
-			code = 501;
-		} else {
-			code = 404;
-		}
 		if (errno == EACCES) {
 			log_error(session, fb_filesystem);
 			code = 403;
+		} else if (session->uri_is_dir) {
+			code = 501;
+		} else {
+			code = 404;
 		}
 	} else {
 		close(handle);
@@ -1171,6 +1174,7 @@ int handle_options_request(t_session *session) {
 	if (session->host->follow_symlinks == false) {
 		switch (contains_not_allowed_symlink(session->file_on_disk, session->host->website_root)) {
 			case error:
+				log_error(session, "error while scanning file for symlinks");
 				code = 500;
 				break;
 			case not_found:
@@ -1528,3 +1532,39 @@ int handle_delete_request(t_session *session) {
 
 	return 204;
 }
+
+#ifdef HAVE_XSLT
+int handle_xml_file(t_session *session) {
+	int handle;
+
+	if ((handle = open(session->file_on_disk, O_RDONLY)) == -1) {
+		if (errno == EACCES) {
+			log_error(session, fb_filesystem);
+			return 403;
+		}
+		return 404;
+	} else {
+		close(handle);
+	}
+
+	/* Symlink check
+	 */
+	if (session->host->follow_symlinks == false) {
+		switch (contains_not_allowed_symlink(session->file_on_disk, session->host->website_root)) {
+			case error:
+				log_error(session, "error while scanning file for symlinks");
+				return 500;
+			case not_found:
+				return 404;
+			case no_access:
+			case yes:
+				log_error(session, fb_symlink);
+				return 403;
+			case no:
+				break;
+		}
+	}
+
+	return transform_xml(session);
+}
+#endif
